@@ -7,7 +7,7 @@ package Games::Simutrans::Pak;
 
 use v5.32;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Mojo::Base -base, -signatures;
 use Mojo::File;
@@ -48,7 +48,7 @@ sub from_string ($self, $params) {
             last;  # Only load the first object.  Caller is responsible for splitting *.dat files.
         }
 
-        if ($line =~ /^\s*(?<object>\w+)\s*(?:\[(?<subscr>(?:\[|\]|\w|\s)+)\])?\s*=(?<nozoom>>?)\s*(?<value>.*?)\s*\Z/) {
+        if ($line =~ /^\s*(?<object>\w+)\s*(?:\[(?<subscr>(?:\[|\]|\-|\w|\s)+)\])?\s*=(?<nozoom>>?)\s*(?<value>.*?)\s*\Z/) {
             # /^\s*(?<object>\w+)\s*(?:\[(?<sub1>\w+)\](?:\[(?<sub2>\w+)\])?)?\s*=\s*(?<value>.*?)\s*\Z/) {
             my ($object, $value, $nozoom) = @+{qw(object value)};
             $object = lc($object);
