@@ -2,7 +2,7 @@ package Games::Simutrans::Pakset;
 
 use v5.32;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Mojo::Base -base, -signatures;
 use Mojo::Path;
@@ -12,16 +12,7 @@ use Path::ExpandTilde;
 
 has 'name';           # An identifying name for the pak
 
-has '_path';          # This must be a path to a pakset's root.
-
-sub path ($self, $path = undef) {
-    return $self->_path unless defined $path;
-    if (ref $path) {
-        return $self->_path($path)
-    } else {
-        return $self->_path(Mojo::Path->new(expand_tilde($path)));
-    }
-}
+has 'path';          # This must be a path to a pakset's root.
 
 sub valid ($self) {
     # Basic check as to whether a valid Pakset exists at the given path
@@ -66,8 +57,8 @@ has 'languages' => sub ($self) {
 has 'language' => sub ($self, $lang = undef) {
     # the default language
     
-    my $l = $lang // $ENV{LANGUAGE} // $ENV{LANG}; $l =~ m/^(..)/;
-    return $1 || 'en';
+    my $l = $lang // $ENV{LANGUAGE} // $ENV{LANG} // 'en'; $l =~ m/^(..)/;
+    return $1;
 };
 
 has 'language_tables' => sub { {}; };
@@ -79,8 +70,8 @@ sub load_language($self, $language = $self->language) {
     my $filename = $lang_file->to_string;
 
     my $translate_from;
-    open TRANSLAT, '<', $filename or die "Can't open translation file $filename\n";
-    while (<TRANSLAT>) {
+    open (my $xlat, '<', $filename) or die "Can't open translation file $filename\n";
+    while (<$xlat>) {
 	chomp;
 	if (/^\s*#(.*)$/) {
 	    my $comment_text = $1;
@@ -97,13 +88,13 @@ sub load_language($self, $language = $self->language) {
 	    }
 	}
     }
-    close TRANSLAT;
+    close $xlat;
 }
 
 sub translate($self, $string, $language = $self->language) {
     # Translate a string, in the given language or the default if none given
     if (!defined $self->language_tables->{$language}) {
-	$self->load_language($language);
+	eval { $self->load_language($language); }
     }
     return '??' unless defined $string;
     return $self->language_tables->{$language}{$string} // $string // '??';
@@ -333,19 +324,22 @@ sub read_dat ($self, $filename) {
 
 sub load ($self, $path = $self->path) {
     # Loads (or reloads) the pak's data files
-    return undef unless defined $path;
 
-    my $file_path = Mojo::File->new($path);
+    if (!ref $path) {
+        $self->path($path = Mojo::File->new(expand_tilde($path)));
+    }
+
+    return undef unless defined $path;
     # Load directory recursively; or load a single file.
-    $self->dat_files( -d $file_path ?
-                      $file_path->list_tree->grep(sub{/\.dat\z/i}) :
-                      Mojo::Collection->new($file_path) );
+    $self->dat_files( -d $path ?
+                      $path->list_tree->grep(sub{/\.dat\z/i}) :
+                      Mojo::Collection->new($path) );
 
     $self->dat_files->each ( sub {
 	$self->read_dat($_);
     });
 
-    $self->load_language();
+    eval { $self->load_language(); 1; } or $self->{_xlat_root}->{error} = $@;
     $self->find_all_images();
     $self->find_image_tile_sizes();
     $self->scan_liveries();
@@ -414,6 +408,8 @@ to pass when creating the object:
 
 =over 4
 
+=item path
+
 =item name
 
 =item language
@@ -429,7 +425,9 @@ an identifier only.
 
 Returns, or sets if an argument is given, the base path on the local
 filesystem for the pakset root.  Tildes are expanded to the user's
-home directory.
+home directory.  After tke pakset is loaded, this will be a Mojo::File
+object (which, when used in scalar context, reduces to the path
+string).
 
 =head2 valid
 
